# -*- coding: utf-8 -*-
"""
Created on Fri Aug 10 14:21:33 2018

@author: Martindrech
"""


from pyqtgraph.Qt import QtCore
import numpy as np
import pyqtgraph as pg
import cv2
from PyQt5.QtCore import QTimer

import sys
from PyQt5.QtWidgets import QMainWindow, QApplication


class roiWindow(QMainWindow):
    
    def __init__(self):
        super().__init__()
        
        
        self.cap = cv2.VideoCapture(1)

        self.n = int(1e2)
        self.data = np.zeros(self.n)
        self.i = 0
        
        self.rois = []
        #self.rois.append(pg.EllipseROI([110, 10], [30, 20], pen=(3,9)))
        self.rois.append(pg.TestROI([0,  0], [20, 20], pen=(0,9)))
        
        
        self.initUI()
        
    def initUI(self):               
        
        ## create GUI
        self.w = pg.GraphicsWindow(size=(800,800), border=True)
        self.v = self.w.addViewBox(colspan=2)
        self.v.invertY(True)  ## Images usually have their Y-axis pointing downward
        self.v.setAspectLocked(True)
        self.im1 = pg.ImageItem(self.capture())
        self.v.addItem(self.im1)


        self.imgTimer = QTimer()
        self.imgTimer.timeout.connect(self.updateImage)
        self.imgTimer.start(10)

        self.im2 = pg.ImageItem()
        self.v2 = self.w.addViewBox(1,0)
        self.v2.addItem(self.im2)


        self.p = self.w.addPlot(row = 3, col = 0,  title="Updating plot")
        self.p.setRange(QtCore.QRectF(0, -10, 5000, 20)) 
        self.p.setAutoPan(y=True)
        self.p.setRange(xRange = (0, self.n), yRange = (0, 255))

        self.curve = self.p.plot(pen='y')


        self.lastRoi = None

        
        ## Add each ROI to the scene and link its data to a plot curve with the same color
        for r in self.rois:
            self.v.addItem(r)
            r.sigRegionChanged.connect(self.updateRoi)
    
        self.w.show()
    
    
    def capture(self):
        ret, frame = self.cap.read()
        #frame = cv2.resize(frame, None, fx = 0.5, fy = 0.5, interpolation = cv2.INTER_CUBIC)
        gray_image = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
        return gray_image

    def updateImage(self):
        self.im1.setImage(self.capture(), cmap = 'Gray')
        self.updateRoi(self.lastRoi)
        
    def updateRoi(self, roi):
        
        if roi is None:
            return
        self.lastRoi = roi
        roiSlice = roi.getArrayRegion(self.im1.image, img=self.im1)
        self.im2.setImage(roiSlice)
        newData = np.mean(roiSlice)
        self.data[self.i] = newData
        self.i = np.mod(self.i + 1, len(self.data))
        self.curve.setData(self.data)
        

    def updateRoiPlot(self, data):
        self.curve.setData(data)
        #app.processEvents()  ## force complete redraw for every plot
        
        
        
if __name__ == '__main__':
    
    app = QApplication(sys.argv)
    ex = roiWindow()
    sys.exit(app.exec_())